@@ -25,23 +25,6 @@
 
 #include <Python.h>
 
-/** Path options */
-int option_set_root_alpm(PyObject *self, PyObject *args, void* closure);
-PyObject * option_get_root_alpm(PyObject *self, void* closure);
-
-int option_set_dbpath_alpm(PyObject *self, PyObject *args, void* closure);
-PyObject * option_get_dbpath_alpm(PyObject *self, void* closure);
-
-int option_set_logfile_alpm(PyObject *self, PyObject *value, void* closure);
-PyObject * option_get_logfile_alpm(PyObject *self, void* closure);
-
-/* read-only */
-PyObject* option_get_lockfile_alpm(PyObject *self, void* closure);
-
-/** string options */
-int option_set_arch_alpm(PyObject *self, PyObject *value, void* closure);
-PyObject* option_get_arch_alpm(PyObject *self, void* closure);
-
 /** boolean options */
 
 PyObject* option_get_usesyslog_alpm(PyObject *self, void* closure);
@@ -82,15 +65,11 @@ PyObject * option_add_ignoregrp_alpm(PyObject *self, PyObject *args);
 PyObject * option_remove_ignoregrp_alpm(PyObject *self, PyObject *args);
 
 /** Callback options */
-int pyalpm_option_set_logcb(PyObject *self, PyObject *value, void *closure);
-int pyalpm_option_set_dlcb(PyObject *self, PyObject *value, void *closure);
-int pyalpm_option_set_totaldlcb(PyObject *self, PyObject *value, void *closure);
-int pyalpm_option_set_fetchcb(PyObject *self, PyObject *value, void *closure);
-PyObject* pyalpm_option_get_logcb(PyObject *self, void *closure);
-PyObject* pyalpm_option_get_dlcb(PyObject *self, void *closure);
-PyObject* pyalpm_option_get_totaldlcb(PyObject *self, void *closure);
-PyObject* pyalpm_option_get_fetchcb(PyObject *self, void *closure);
+void pyalpm_logcb(alpm_loglevel_t level, const char *fmt, va_list va_args);
+void pyalpm_dlcb(const char *filename, off_t xfered, off_t total);
+void pyalpm_totaldlcb(off_t total);
+int pyalpm_fetchcb(const char *url, const char *localpath, int force);
 
-#endif // _PY_ALPM_OPTIONS_H
+#endif
 
 /* vim: set ts=2 sw=2 et: */
